@@ -4,7 +4,8 @@
 #                                                                              #
 # Copyright 2015 Ed Holland <eholland@alertlogic.com>                          #
 #                                                                              #
-# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
+# This file is part of PyGithub.                                               #
+# http://pygithub.github.io/PyGithub/v1/index.html                             #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -30,6 +31,9 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
     This class represents GitRelease as returned for example by https://developer.github.com/v3/repos/releases
     """
 
+    def __repr__(self):
+        return self.get__repr__({"title": self._title.value})
+
     @property
     def body(self):
         """
