@@ -47,6 +47,9 @@ class Issue(github.GithubObject.CompletableGithubObject):
     This class represents Issues as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({"number": self._number.value, "title": self._title.value})
+
     @property
     def assignee(self):
         """
