@@ -41,6 +41,9 @@ class Team(Framework.TestCase):
         self.assertEqual(self.team.repos_count, 0)
         self.assertEqual(self.team.url, "https://api.github.com/teams/189850")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.team.__repr__(), 'Team(name="Team created by PyGithub", id=189850)')
+
     def testMembers(self):
         user = self.g.get_user("jacquev6")
         self.assertListKeyEqual(self.team.get_members(), None, [])
